@@ -49,7 +49,7 @@ from bluetooth_mesh.messages.config import (
     PublishPeriodStepResolution,
 )
 from bluetooth_mesh.messages.properties import PropertyID
-from bluetooth_mesh.messages.time import TimeRole, UNCERTAINTY_MS, CURRENT_TAI_UTC_DELTA
+from bluetooth_mesh.messages.time import CURRENT_TAI_UTC_DELTA, UNCERTAINTY_MS, TimeRole
 from bluetooth_mesh.models import (
     ConfigClient,
     ConfigServer,
@@ -413,7 +413,7 @@ class TtlCommand(ConfigCommand):
     PARAMETER = "default_ttl"
 
     def format(self, data):
-        return data["TTL"]
+        return data["ttl"]
 
 
 class RelayCommand(ConfigCommand):
@@ -491,7 +491,7 @@ class PublicationCommand(ModelCommandMixin, NodeSelectionCommandMixin, Command):
                     element_address=address + element_index,
                     publication_address=int(arguments["--address"], 16),
                     app_key_index=int(arguments["--key-index"]),
-                    TTL=int(arguments["--ttl"]),
+                    ttl=int(arguments["--ttl"]),
                     publish_step_resolution=resolution,
                     publish_number_of_steps=steps,
                     retransmit_count=int(arguments["--count"]),
@@ -572,15 +572,23 @@ class AddSubscriptionCommand(ModelCommandMixin, NodeSelectionCommandMixin, Comma
         model = self.get_model(application)
         destinations = self.get_addresses(application, arguments)
 
-        element = int(arguments["--element"]) if arguments["--element"] is not None else 0
-        address = int(arguments["--address"], 16) if arguments["--address"] is not None else 0
+        element = (
+            int(arguments["--element"]) if arguments["--element"] is not None else 0
+        )
+        address = (
+            int(arguments["--address"], 16) if arguments["--address"] is not None else 0
+        )
         if not destinations:
             yield "invalid uuid!"
         for dst in destinations:
             element_address = dst + element
 
             results = await model.add_subscription(
-                dst, 0, element_address, address, model=getattr(models, arguments["--model"])
+                dst,
+                0,
+                element_address,
+                address,
+                model=getattr(models, arguments["--model"]),
             )
 
             node = application.network.get_node(address=dst)
@@ -613,14 +621,23 @@ class BindAppKeyCommand(ModelCommandMixin, NodeSelectionCommandMixin, Command):
         if not destinations:
             yield "invalid uuid!"
 
-        element = int(arguments["--element"]) if arguments["--element"] is not None else 0
-        key_index = int(arguments["--keyindex"]) if arguments["--keyindex"] is not None else 0
+        element = (
+            int(arguments["--element"]) if arguments["--element"] is not None else 0
+        )
+        key_index = (
+            int(arguments["--keyindex"]) if arguments["--keyindex"] is not None else 0
+        )
 
         for dst in destinations:
             element_address = dst + element
 
             results = await model.bind_app_key(
-                dst, 0, element_address, key_index, model=getattr(models, arguments["--model"]))
+                dst,
+                0,
+                element_address,
+                key_index,
+                model=getattr(models, arguments["--model"]),
+            )
 
             node = application.network.get_node(address=dst)
             if results is None:
@@ -950,7 +967,9 @@ class LightRangeCommand(ModelGetCommandMixin, NodeSelectionCommandMixin, Command
     async def __call__(self, application, arguments):
         max_lightness_arg = arguments["--max"]
         if max_lightness_arg is None:
-            async for i in super(LightRangeCommand, self).__call__(application, arguments):
+            async for i in super(LightRangeCommand, self).__call__(
+                application, arguments
+            ):
                 yield i
             return
 
@@ -966,7 +985,7 @@ class LightRangeCommand(ModelGetCommandMixin, NodeSelectionCommandMixin, Command
                     app_index=0,
                     destination=address,
                     min_lightness=min_lightness,
-                    max_lightness=max_lightness
+                    max_lightness=max_lightness,
                 )
                 for address in addresses
             )
@@ -977,7 +996,7 @@ class LightRangeCommand(ModelGetCommandMixin, NodeSelectionCommandMixin, Command
                         app_index=0,
                         destination=address,
                         min_lightness=min_lightness,
-                        max_lightness=max_lightness
+                        max_lightness=max_lightness,
                     )
                 except asyncio.TimeoutError:
                     result = None
@@ -1047,17 +1066,17 @@ class CompositionDataCommand(ModelCommandMixin, NodeSelectionCommandMixin, Comma
 
             yield "{}: CID {}, PID {}, VID {}, CRPL {}, Features {:016b}".format(
                 node.name,
-                composition["CID"],
-                composition["PID"],
-                composition["VID"],
-                composition["CRPL"],
+                composition["cid"],
+                composition["pid"],
+                composition["vid"],
+                composition["crpl"],
                 composition["features"],
             )
 
             for i, ele in enumerate(composition["elements"]):
                 yield "\tElement {}, location: {}".format(i, ele["location"])
                 yield "\t\t   SIG Models: " + ", ".join(
-                    "{:04x}".format(mod["model_id"]) for mod in ele["SIG_models"]
+                    "{:04x}".format(mod["model_id"]) for mod in ele["sig_models"]
                 )
                 yield "\t\tVendor Models: " + ", ".join(
                     "{:04x}:{:04x}".format(mod["vendor_id"], mod["model_id"])
@@ -1538,7 +1557,9 @@ class MeshCommandLine(*application_mixins, Application):
         self.history = FileHistory(f"{self.config_dir}/history")
         self.completer = MeshCompleter(self)
         self.session = PromptSession(
-            history=self.history, completer=self.completer, complete_while_typing=False,
+            history=self.history,
+            completer=self.completer,
+            complete_while_typing=False,
         )
         self.commands = {cmd.CMD: cmd() for cmd in self.COMMANDS}
         self._tid = 0
