@@ -1,9 +1,9 @@
 from construct import Select
 
-from .onoff import GenericOnOffMessage
 from .level import GenericLevelMessage
 from .light.ctl import LightCTLMessage, LightCTLSetupMessage
 from .light.lightness import LightLightnessMessage, LightLightnessSetupMessage
+from .onoff import GenericOnOffMessage
 
 GenericMessage = Select(
     GenericOnOffMessage,
@@ -11,5 +11,5 @@ GenericMessage = Select(
     LightCTLMessage,
     LightCTLSetupMessage,
     LightLightnessMessage,
-    LightLightnessSetupMessage
+    LightLightnessSetupMessage,
 )
