@@ -21,10 +21,10 @@
 #
 # pylint: disable=redefined-outer-name, invalid-name
 import asynctest
-from asynctest import ANY, mock, call
+from asynctest import ANY, call, mock
 
 from bluetooth_mesh import Element, LightLightnessClient
-from bluetooth_mesh.messages import LightLightnessOpcode, LightLightnessMessage
+from bluetooth_mesh.messages import LightLightnessMessage, LightLightnessOpcode
 from bluetooth_mesh.messages.config import GATTNamespaceDescriptor
 from bluetooth_mesh.messages.generic import LightLightnessSetupMessage
 from bluetooth_mesh.messages.generic.light import LightLightnessSetupOpcode
@@ -62,7 +62,7 @@ async def test_sending_set_lightness_range_repeated_6_times_with_intervals_by_de
 @pytest.mark.asyncio
 @asynctest.patch("asyncio.sleep", new=asynctest.CoroutineMock())
 async def test_sending_set_lightness_repeated_6_times_with_intervals_by_default(
-        light_lightness_client, destination, app_index
+    light_lightness_client, destination, app_index
 ):
     light_lightness_client.repeat = asynctest.CoroutineMock()
 
@@ -89,8 +89,11 @@ async def test_set_lightness_range_calls_node_interface_with_appropriate_argumen
 
     data = LightLightnessSetupMessage.build(
         {
-            "opcode": LightLightnessSetupOpcode.LIGHTNESS_RANGE_SET_UNACKNOWLEDGED,
-            "params": {"range_min": 0, "range_max": 100,},
+            "opcode": LightLightnessSetupOpcode.LIGHT_LIGHTNESS_SETUP_RANGE_SET_UNACKNOWLEDGED,
+            "params": {
+                "range_min": 0,
+                "range_max": 100,
+            },
         }
     )
     light_lightness_client._node_interface.send.assert_awaited_with(
@@ -102,7 +105,7 @@ async def test_set_lightness_range_calls_node_interface_with_appropriate_argumen
 @pytest.mark.asyncio
 @asynctest.patch("asyncio.sleep", new=asynctest.CoroutineMock())
 async def test_set_lightness_calls_node_interface_with_appropriate_arguments(
-        light_lightness_client, destination, app_index, element_path
+    light_lightness_client, destination, app_index, element_path
 ):
     light_lightness_client._node_interface.send = asynctest.CoroutineMock()
 
@@ -116,12 +119,13 @@ async def test_set_lightness_calls_node_interface_with_appropriate_arguments(
     )
 
     frames = [
-        LightLightnessMessage.build({
-            "opcode": LightLightnessOpcode.LIGHTNESS_SET_UNACKNOWLEDGED,
-            "params": dict(lightness=0, tid=0, transition_time=0, delay=d)
-        }) for d in [
-            0.50, 0.45, 0.40, 0.35, 0.30, 0.25
-        ]
+        LightLightnessMessage.build(
+            {
+                "opcode": LightLightnessOpcode.LIGHT_LIGHTNESS_SET_UNACKNOWLEDGED,
+                "params": dict(lightness=0, tid=0, transition_time=0, delay=d),
+            }
+        )
+        for d in [0.50, 0.45, 0.40, 0.35, 0.30, 0.25]
     ]
     assert light_lightness_client._node_interface.send.await_args_list == [
         call(element_path, destination, app_index, frame) for frame in frames
